@@ -2,14 +2,12 @@
 # -*- coding: utf-8 -*-
 
 from api import Api, EverysportException
-import stats
-
-
+import results
 
 '''Teams from everysport.com
 '''
 
-from data import Team 
+from teams import Team 
 
 MFF = Team(9375,u"Malmö FF", "", "")
 HBG = Team(9373,u"Helingsborgs IF", "", "")
